\name{mLDM}
\alias{mLDM}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Metagenomic Lognormal-Dirichlet-Multinomial Model
}
\description{
Microbial sparse association estimation between pairs of species and environemental factors and the species}
\usage{
mLDM(X, M, Z_mean = 1, max_iteration = 1500, threshold = 1e-04, approx_num_Z = 10, max_linesearch_Z = 30, model_selection_num = 6, approx_num_B = 10, max_linesearch_B = 30, max_iteration_B = 500, threshold_B = 1e-05, delta1_threshold_B = 1e-04, delta2_threshold_B = 0.9, sy_threshold_B = 1e-06, max_iteration_B_coor = 20, threshold_B_coor = 1e-06, ratio1 = 0.6, ratio2 = 0.9, verbose = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{X}{
n*p matrix, OTU data. n is the number of samples and p is the number of OTUs
}
  \item{M}{
n*q matrix, Meta data. q is the number of meta data
}
  \item{Z_mean}{
A positive integer for initalization for latent variable Z
          default is 1, but need to set Z_mean a little bit large when
           the biggest OTU is >> the smallest OTU, try to maintain the
           minimum of latent variable Z >= 0
}
  \item{max_iteration}{
The number of max iterations
}
  \item{threshold}{
The threshold for termination
}
  \item{approx_num_Z}{
The number of gradient vector to approximate the hessian matrix for Z
}
  \item{max_linesearch_Z}{
The number of line search of proximal method for Z
}
  \item{model_selection_num}{
The number of different lambda to select model, the model_selection_num*model_selection_num combinations of lambda1 and lambda2 will be tested
}
\item{approx_num_B}{
The number of gradient vector to approximate the hessian matrix for B
}
  \item{max_linesearch_B}{
The number of line search of proximal method for B
}
  \item{max_iteration_B}{
The max iterations for B
}
  \item{threshold_B}{
The threshold for termination for B
}
  \item{delta1_threshold_B}{
The parameter of line search based on strong wolfe condition for B
}
  \item{delta2_threshold_B}{
The parameter of line search based on strong wolfe condition for B
}
  \item{sy_threshold_B}{
When the positive difinite condition is not hold, change to steepest descent
}
  \item{max_iteration_B_coor}{
The max iteration of coordinate descent when optimize B
}
  \item{threshold_B_coor}{
Stop the coordinate descent when the the variation of the direction samll than the threshold
}
  \item{ratio1}{
Set ratio1 to control minimum values of lambda1 and lambda2.
}
  \item{ratio2}{
Set ratio2 to control maximum values of lambda1 and lambda2.
}
  \item{verbose}{
 Set FALSE to run mLDM at a silent mode;
 set TRUE to see the debug information from the program.
}
}
\details{
Associations among OTUs and between environmental factors and OTUs are parametered by the matrix Theta (p*p) and B (q*p), which are estimated respectively. The latent variable Z is estimated via L-BFGS algorithm; then
the matrix B is split into q vectors (p*1) to estimate values separately by proximal Newton method; finally the Theta is estimated by graphical lasso.
}
\value{
a list consists of optimal and all results from mLDM are returned:
  \item{list$optimal}{the optimal result via the model selection}
  \item{list$all}{all results corresponding to different lambda1 and lambda2}
  \item{list$lambda1}{the list of all lambda1}
  \item{list$lambda2}{the list of all lambda2}

}
\references{
doi: http://dx.doi.org/10.1101/042630
}
\author{
Yuqing Yang, Ning Chen and Ting Chen.
Maintainers: Yuqing Yang <yangyq14@mails.tsinghua.edu.cn>
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
}
\examples{
n = 100
p = 10
q = 3
X <- matrix(floor(runif(n*p, 1, 10)), n, p)
M <- matrix(runif(n*q), n, q)
result <- mLDM(X, M, Z_mean = 1)
# NOTE:

# The optimal result selected by model selection
resultOptimal <- result$optimal
# Theta is the precision matrix, the sign of Theta_ij is opposite with the association between OTU-i and OTU-j
Theta <- resultOptimal[[3]]
# B records the associations between EFs and OTUs
B <- resultOptimal[[1]]
# B0 records the baisc abundance of OTUs
B0 <- resultOptimal[[2]]
# Z record the latent variables of mLDM
Z <- resultOptimal[[4]]
# the best lambda1
lambda1 <- resultOptimal[[5]]
# the best lambda2
lambda2 <- resultOptimal[[6]]
EBIC <- resultOptimal[[7]]
# Associations among OTUs and OTUs
Associations_OTU_OTU <- resultOptimal[[9]]
# Associations between environmental factors and OTUs
Associations_EF_OTU <- resultOptimal[[8]]

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ L-BFGS }
\keyword{ Proximal Newton }% __ONLY ONE__ keyword per line
\keyword{ Graphical lasso }
